CoolDropdown class

Inheritance

Constructors

CoolDropdown({required List dropdownList, required Function onChange, dynamic resultIcon, dynamic placeholderTS, bool dropdownItemReverse = false, bool resultReverse = false, bool resultIconRotation = true, bool isTriangle = true, bool isResultLabel = true, String placeholder = '', double resultWidth = 220, double resultHeight = 50, double dropdownWidth = 200, double dropdownHeight = 300, double dropdownItemHeight = 50, Alignment resultAlign = Alignment.centerLeft, String dropdownAlign = 'center', String triangleAlign = 'center', Alignment dropdownItemAlign = Alignment.centerLeft, MainAxisAlignment dropdownItemMainAxis = MainAxisAlignment.spaceBetween, MainAxisAlignment resultMainAxis = MainAxisAlignment.spaceBetween, EdgeInsets resultPadding = const EdgeInsets.only(left: 10, right: 10), EdgeInsets dropdownItemPadding = const EdgeInsets.only(left: 10, right: 10), EdgeInsets dropdownPadding = const EdgeInsets.only(left: 10, right: 10), EdgeInsets selectedItemPadding = const EdgeInsets.only(left: 10, right: 10), dynamic resultBD, dynamic dropdownBD, dynamic selectedItemBD, dynamic selectedItemTS, dynamic unselectedItemTS, dynamic resultTS, double labelIconGap = 10, double dropdownItemGap = 5, double dropdownItemTopGap = 10, double dropdownItemBottomGap = 10, double resultIconLeftGap = 10, double gap = 30, double triangleWidth = 20, double triangleHeight = 20, double triangleLeft = 0, bool isAnimation = true, bool isResultIconLabel = true, double resultIconRotationValue = 0.5, bool isDropdownLabel = true, dynamic defaultValue, required Key key})

Properties

defaultValue ↔ Map
getter/setter pair
getter/setter pair
getter/setter pair
getter/setter pair
getter/setter pair
getter/setter pair
getter/setter pair
getter/setter pair
getter/setter pair
getter/setter pair
getter/setter pair
getter/setter pair
getter/setter pair
getter/setter pair
getter/setter pair
gap ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAnimation ↔ bool
getter/setter pair
isDropdownLabel ↔ bool
getter/setter pair
isResultIconLabel ↔ bool
getter/setter pair
isResultLabel ↔ bool
getter/setter pair
isTriangle ↔ bool
getter/setter pair
key ↔ Key
Controls how one widget replaces another widget in the tree.
getter/setter pairoverride-getter
labelIconGap ↔ double
getter/setter pair
onChange ↔ Function
getter/setter pair
placeholder ↔ String
getter/setter pair
placeholderTS ↔ TextStyle
getter/setter pair
resultAlign ↔ Alignment
getter/setter pair
resultBD ↔ BoxDecoration
getter/setter pair
resultHeight ↔ double
getter/setter pair
resultIcon ↔ Widget
getter/setter pair
resultIconLeftGap ↔ double
getter/setter pair
resultIconRotation ↔ bool
getter/setter pair
resultIconRotationValue ↔ double
getter/setter pair
resultMainAxis ↔ MainAxisAlignment
getter/setter pair
resultPadding ↔ EdgeInsets
getter/setter pair
resultReverse ↔ bool
getter/setter pair
resultTS ↔ TextStyle
getter/setter pair
resultWidth ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedItemBD ↔ BoxDecoration
getter/setter pair
selectedItemPadding ↔ EdgeInsets
getter/setter pair
selectedItemTS ↔ TextStyle
getter/setter pair
triangleAlign ↔ String
getter/setter pair
triangleHeight ↔ double
getter/setter pair
triangleLeft ↔ double
getter/setter pair
triangleWidth ↔ double
getter/setter pair
unselectedItemTS ↔ TextStyle
getter/setter pair

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → CoolDropdownState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited