DropdownBodyState class

Inheritance
Mixed-in types

Constructors

Properties

animateHeight ↔ Animation<double>
getter/setter pair
au ↔ AnimationUtil
getter/setter pair
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
currentIndex ↔ int
getter/setter pair
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isOpen ↔ bool
getter/setter pair
isSelected ↔ bool
getter/setter pair
isTap ↔ bool
getter/setter pair
isTop ↔ bool
getter/setter pair
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedDecorationTween ↔ DecorationTween
getter/setter pair
selectedItemAnimation ↔ Animation<double>
getter/setter pair
selectedLabel ↔ String
getter/setter pair
selectedPaddingTween ↔ EdgeInsetsTween
getter/setter pair
selectedTSTween ↔ TextStyleTween
getter/setter pair
triangleAnimation ↔ Animation<double>
getter/setter pair
triangleOffset ↔ Offset
getter/setter pair
upsideDown ↔ bool
getter/setter pair
widget → DropdownBody
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
animationForward() → Future
animationReverse() → Future
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
closeAnimation() → void
createTicker(TickerCallback onTick) → Ticker
Creates a ticker with the given callback.
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant DropdownBody oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
override
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setAnimation() → void
setDropdownPosition({required bool isTop, required double sidePadding, required dynamic inputBox, required Offset inputPosition, required double actualBoxHeight}) → Offset
setOffset() → void
setScrollPosition(int currentIndex) → void
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
setTrianglePosition({required Offset dropdownOffset, required double sidePadding}) → Offset
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited