DateInfo class

Constructors

DateInfo({int? weekday, int? date, required SelectType isSelected, AnimationController? singleSelectedAniCtrl, Animation<double>? singleScaleAnimation})

Properties

date ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isSelected ↔ SelectType
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
singleScaleAnimation ↔ Animation<double>?
getter/setter pair
singleSelectedAniCtrl ↔ AnimationController?
getter/setter pair
weekday ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited