CalendarState class

Inheritance
Mixed-in types

Constructors

CalendarState()

Properties

animationBGBlur ↔ Animation<double>?
getter/setter pair
animationBGColor ↔ Animation<Color?>?
getter/setter pair
animationBorderExpand ↔ Animation<double>
getter/setter pair
animationCalendarLeft ↔ Animation<double>?
getter/setter pair
animationCalendarTop ↔ Animation<double>?
getter/setter pair
animationController ↔ AnimationController
getter/setter pair
animationPadding ↔ Animation<double>?
getter/setter pair
animationScale ↔ Animation<double>?
getter/setter pair
betweenControllerList ↔ List<AnimationController>
getter/setter pair
bottomBorderCtrl ↔ AnimationController
getter/setter pair
bottomBorderExpandCtrl ↔ AnimationController
getter/setter pair
bottomListKey ↔ GlobalKey<AnimatedListState>
getter/setter pair
bottomRangeBorderExpandWidth ↔ double
getter/setter pair
bottomRangeBorderHeight ↔ double
getter/setter pair
bottomRangeBorderWidth ↔ double
getter/setter pair
bottomRangeBtnCtrl ↔ AnimationController
getter/setter pair
bottomRightSizedWidth ↔ double
getter/setter pair
bottomSelectedItems ↔ List<DateTime>?
getter/setter pair
calendarInfo ↔ CalendarInfo
getter/setter pair
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
datesRange ↔ DatesRange
getter/setter pair
endController ↔ AnimationController
getter/setter pair
endDateStr ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isRight ↔ bool
getter/setter pair
monthDropdown ↔ GlobalKey<CoolDropdownState>
getter/setter pair
monthValue ↔ Map
getter/setter pair
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
nullAnimation ↔ Animation<double>
getter/setter pair
paddingController ↔ AnimationController
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedItems ↔ List<DateTime>?
getter/setter pair
selectedItemsHistory ↔ List<DateTime?>
getter/setter pair
selectedRangeItem ↔ Map<String, DateTime?>?
getter/setter pair
startController ↔ AnimationController
getter/setter pair
startDateStr ↔ String
getter/setter pair
widget → Calendar
The current configuration.
no setterinherited
yearDropdown ↔ GlobalKey<CoolDropdownState>
getter/setter pair
yearValue ↔ Map
getter/setter pair

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
arrowButton({required double width, required String type}) → Widget
betweenArea(DateInfo date, double width, int index) → Widget
bottomButton(BuildContext context, int index, dynamic animation) → Widget
bottomRangeLabel({required double width, DateTime? target, required bool isStart}) → Widget
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
controlCalendar({required int number}) → void
createTicker(TickerCallback onTick) → Ticker
Creates a ticker with the given callback.
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant Calendar oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
endArea(DateInfo date, double width, int index) → Widget
findIndex({required List list, required Map target}) → int
findValue({required List list, required int value}) → Map
getCenterPosition(double fullWidth, double fullHeight, double calendarWidth, double calendarHeight) → Offset
getFontWidth(String text, TextStyle style, BuildContext context) → double
getFullCalendarHeight(double calendarSize) → double
getFullCalendarWidth(double calendarSize) → double
initState() → void
Called when this object is inserted into the tree.
override
innerCircle(DateInfo date, double width, int index) → Widget
limitCalendar({required int number}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
outerCircle(DateInfo date, double width, int index) → Widget
range({required CalendarInfo calendarInfo, required DateInfo date, required double width, required int index}) → Widget
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
removeBottomSelectedItems(DateInfo date, CalendarInfo calenderInfo) → void
removeBottomSelectedItemsXBtn(int index) → void
resetBetweenControllerList() → void
resetCalendar() → void
setBottomEndFormat({int? yyyy, int? mm, int? dd}) → void
setBottomSelectedItems(DateTime selectedItem) → void
setBottomStartFormat({int? yyyy, int? mm, int? dd}) → void
setCalcYearValue({required int calcYearValue}) → void
setCalendar() → void
setDarkColor() → Color
setFormat({int? yyyy, int? mm, int? dd}) → String
setOrderRangeAnimation(int startIndex, int endIndex) → void
setPreSelected() → void
setRangeSelect() → void
setSizedBottomRightBtn({required double defaultSize, required double oneSelectedSize, required double multipleSelectedSize}) → void
setStart({required DateInfo date, required DateTime selectedDates}) → void
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
single({required CalendarInfo calendarInfo, required DateInfo date, required double width}) → Widget
sizedWidget({required Widget child, required AnimationController sizeFactor, required bool condition}) → Widget
startArea(DateInfo date, double width, int index) → Widget
textColor(SelectType selectType) → Color
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
wrapCalendar({required Widget child}) → Widget

Operators

operator ==(Object other) → bool
The equality operator.
inherited